about summary refs log tree commit diff
path: root/nptl/allocatestack.c
diff options
context:
space:
mode:
Diffstat (limited to 'nptl/allocatestack.c')
-rw-r--r--nptl/allocatestack.c9
1 files changed, 6 insertions, 3 deletions
diff --git a/nptl/allocatestack.c b/nptl/allocatestack.c
index 4aec875548..31cff2a1c2 100644
--- a/nptl/allocatestack.c
+++ b/nptl/allocatestack.c
@@ -439,9 +439,12 @@ allocate_stack (const struct pthread_attr *attr, struct pthread **pdp,
 
 	      lll_unlock (stack_cache_lock);
 
-	      /* Free the memory regardless of whether the size of the
-		 cache is over the limit or not.  If this piece of
-		 memory caused problems we better do not use it
+	      /* Get rid of the TLS block we allocated.  */
+	      _dl_deallocate_tls (pd, false);
+
+	      /* Free the stack memory regardless of whether the size
+		 of the cache is over the limit or not.  If this piece
+		 of memory caused problems we better do not use it
 		 anymore.  Uh, and we ignore possible errors.  There
 		 is nothing we could do.  */
 	      (void) munmap (mem, size);